Struct twilight_validate::command::CommandValidationError
source · [−]pub struct CommandValidationError { /* private fields */ }Expand description
Error created when a Command is invalid.
Implementations
sourceimpl CommandValidationError
impl CommandValidationError
sourcepub const COMMAND_COUNT_INVALID: CommandValidationError
pub const COMMAND_COUNT_INVALID: CommandValidationError
Constant instance of a CommandValidationError with type
CountInvalid.
sourcepub const fn kind(&self) -> &CommandValidationErrorType
pub const fn kind(&self) -> &CommandValidationErrorType
Immutable reference to the type of error that occurred.
sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
sourcepub fn into_parts(
self
) -> (CommandValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts(
self
) -> (CommandValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.
sourcepub const fn option_required_first(index: usize) -> Self
pub const fn option_required_first(index: usize) -> Self
Create an error of type OptionsRequiredFirst with a provided index.