pub struct ComponentValidationError { /* private fields */ }Expand description
A provided Component is invalid.
While multiple components may be invalid, validation will short-circuit on the first invalid component.
Implementations
sourceimpl ComponentValidationError
impl ComponentValidationError
sourcepub const fn kind(&self) -> &ComponentValidationErrorType
pub const fn kind(&self) -> &ComponentValidationErrorType
Immutable reference to the type of error that occurred.
sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
sourcepub fn into_parts(
self
) -> (ComponentValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts(
self
) -> (ComponentValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.