#[non_exhaustive]
pub enum EmbedValidationErrorType {
AuthorNameTooLarge {
chars: usize,
},
ColorNotRgb {
color: u32,
},
DescriptionTooLarge {
chars: usize,
},
EmbedTooLarge {
chars: usize,
},
FieldNameTooLarge {
chars: usize,
},
FieldValueTooLarge {
chars: usize,
},
FooterTextTooLarge {
chars: usize,
},
TitleTooLarge {
chars: usize,
},
TooManyFields {
amount: usize,
},
}Expand description
Type of EmbedValidationError that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AuthorNameTooLarge
Fields
chars: usizeProvided number of codepoints.
Embed author’s name is larger than AUTHOR_NAME_LENGTH.
ColorNotRgb
Fields
color: u32Provided color hex value.
Color is larger than a valid RGB hexadecimal value.
DescriptionTooLarge
Fields
chars: usizeProvided number of codepoints.
Embed description is larger than DESCRIPTION_LENGTH.
EmbedTooLarge
Fields
chars: usizeProvided number of codepoints.
Combined content of all embed fields is larger than
EMBED_TOTAL_LENGTH.
This includes author name, description, footer, field names and values, and title.
FieldNameTooLarge
Fields
chars: usizeProvided number of codepoints.
A field’s name is larger than FIELD_NAME_LENGTH.
FieldValueTooLarge
Fields
chars: usizeProvided number of codepoints.
A field’s value is larger than FIELD_VALUE_LENGTH.
FooterTextTooLarge
Footer text is larger than FOOTER_TEXT_LENGTH.
TitleTooLarge
Fields
chars: usizeProvided number of codepoints.
Title is larger than TITLE_LENGTH.
TooManyFields
Fields
amount: usizeProvided number of fields.
There are more than FIELD_COUNT number of fields in the embed.