Function twilight_validate::message::components
source · [−]Expand description
Ensure a list of components is correct.
Errors
Returns a ComponentValidationErrorType::ComponentCount if there are
too many components in the provided list.
Refer to the errors section of component for a list of errors that may
be returned as a result of validating each provided component.