Struct twilight_validate::message::MessageValidationError
source · [−]pub struct MessageValidationError { /* private fields */ }Expand description
A message is not valid.
Implementations
sourceimpl MessageValidationError
impl MessageValidationError
sourcepub const fn kind(&self) -> &MessageValidationErrorType
pub const fn kind(&self) -> &MessageValidationErrorType
Immutable reference to the type of error that occurred.
sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
sourcepub fn into_parts(
self
) -> (MessageValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts(
self
) -> (MessageValidationErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.