Module twilight_validate::command
source · Expand description
Constants, error types, and functions for validating Commands.
Structs
- Error created when a
Commandis invalid.
Enums
- Type of
CommandValidationErrorthat occurred.
Constants
- Maximum number of choices an option can have.
- The maximum combined command length in codepoints.
- Maximum length of a command’s description.
- Minimum length of a command’s description.
- Maximum number of commands an application may have in an individual guild.
- Maximum number of permission overwrites an application may have in an individual guild command.
- Maximum length of a command’s name.
- Minimum length of a command’s name.
- Maximum amount of options a command may have.
- Maximum length of an option choice name.
- Minimum length of an option choice name.
- Maximum length of an option choice string value.
- Minimum length of an option choice string value.
- Maximum length of a command’s description.
- Minimum length of a command’s description.
- Maximum length of a command’s name.
- Minimum length of a command’s name.
Functions
- Validate the name of a
ChatInputcommand. - Validate a single
CommandOptionChoice. - Validate a single name localization in a
CommandOptionChoice. - Validate a
Command. - Calculate the total character count of a command.
- Validate the description of a
Command. - Validate the number of guild command permission overwrites.
- Validate a single
CommandOption. - Calculate the total character count of a command option.
- Validate the name of a
CommandOption. - Validate a list of command options for count, order, and internal validity.