#[non_exhaustive]
pub enum ComponentValidationErrorType {
Show 13 variants
ActionRowComponentCount {
count: usize,
},
ComponentCount {
count: usize,
},
ComponentCustomIdLength {
chars: usize,
},
ComponentLabelLength {
chars: usize,
},
InvalidChildComponent {
kind: ComponentType,
},
InvalidRootComponent {
kind: ComponentType,
},
SelectMaximumValuesCount {
count: usize,
},
SelectMinimumValuesCount {
count: usize,
},
SelectOptionCount {
count: usize,
},
SelectOptionDescriptionLength {
chars: usize,
},
SelectOptionLabelLength {
chars: usize,
},
SelectOptionValueLength {
chars: usize,
},
SelectPlaceholderLength {
chars: usize,
},
}Expand description
Type of ComponentValidationError that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ActionRowComponentCount
Fields
count: usizeNumber of components within the action row.
Number of components a provided ActionRow is larger than
the maximum.
ComponentCount
Fields
count: usizeNumber of components that were provided.
Number of components provided is larger than the maximum.
ComponentCustomIdLength
Fields
chars: usizeNumber of codepoints that were provided.
Component custom ID is larger than the the maximum.
ComponentLabelLength
Fields
chars: usizeNumber of codepoints that were provided.
Component label is larger than the maximum.
InvalidChildComponent
Fields
kind: ComponentTypeType of provided component.
Provided component cannot be a child component.
InvalidRootComponent
Fields
kind: ComponentTypeType of provided component.
Provided component cannot be a root component.
SelectMaximumValuesCount
Fields
count: usizeNumber of options that were provided.
Maximum number of items that can be chosen is smaller than the minimum or larger than the maximum.
SelectMinimumValuesCount
Fields
count: usizeNumber of options that were provided.
Minimum number of items that must be chosen is larger than the maximum.
SelectOptionCount
Fields
count: usizeNumber of options that were provided.
Number of select menu options provided is larger than the maximum.
SelectOptionDescriptionLength
Fields
chars: usizeNumber of codepoints that were provided.
Description of a select menu option is larger than the maximum.
SelectOptionLabelLength
Fields
chars: usizeNumber of codepoints that were provided.
Label of a select menu option is larger than the maximum.
SelectOptionValueLength
Fields
chars: usizeNumber of codepoints that were provided.
Value of a select menu option is larger than the maximum.
SelectPlaceholderLength
Fields
chars: usizeNumber of codepoints that were provided.
Placeholder of a component is larger than the maximum.