#[non_exhaustive]
pub enum EmbedValidationErrorType {
    AuthorNameTooLarge {
        chars: usize,
    },
    DescriptionTooLarge {
        chars: usize,
    },
    EmbedTooLarge {
        chars: usize,
    },
    FieldNameTooLarge {
        chars: usize,
    },
    FieldValueTooLarge {
        chars: usize,
    },
    FooterTextTooLarge {
        chars: usize,
    },
    TitleTooLarge {
        chars: usize,
    },
    TooManyFields {
        amount: usize,
    },
}
Type of EmbedValidationError that occurred.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.

AuthorNameTooLarge

Fields

chars: usize

The number of codepoints that were provided.

The embed author’s name is larger than the maximum.

DescriptionTooLarge

Fields

chars: usize

The number of codepoints that were provided.

The embed description is larger than the maximum.

EmbedTooLarge

Fields

chars: usize

The number of codepoints that were provided.

The combined content of all embed fields - author name, description, footer, field names and values, and title - is larger than the maximum.

FieldNameTooLarge

Fields

chars: usize

The number of codepoints that were provided.

A field’s name is larger than the maximum.

FieldValueTooLarge

Fields

chars: usize

The number of codepoints that were provided.

A field’s value is larger than the maximum.

FooterTextTooLarge

Fields

chars: usize

The number of codepoints that were provided.

The footer text is larger than the maximum.

TitleTooLarge

Fields

chars: usize

The number of codepoints that were provided.

The title is larger than the maximum.

TooManyFields

Fields

amount: usize

The number of fields that were provided.

There are more than the maximum number of fields in the embed.