#[non_exhaustive]
pub enum EmbedValidationErrorType {
AuthorNameTooLarge {
chars: usize,
},
DescriptionTooLarge {
chars: usize,
},
EmbedTooLarge {
chars: usize,
},
FieldNameTooLarge {
chars: usize,
},
FieldValueTooLarge {
chars: usize,
},
FooterTextTooLarge {
chars: usize,
},
TitleTooLarge {
chars: usize,
},
TooManyFields {
amount: usize,
},
}Expand description
Type of EmbedValidationError that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AuthorNameTooLarge
Fields
chars: usizeThe number of codepoints that were provided.
The embed author’s name is larger than the maximum.
DescriptionTooLarge
Fields
chars: usizeThe number of codepoints that were provided.
The embed description is larger than the maximum.
EmbedTooLarge
Fields
chars: usizeThe number of codepoints that were provided.
The combined content of all embed fields - author name, description, footer, field names and values, and title - is larger than the maximum.
FieldNameTooLarge
Fields
chars: usizeThe number of codepoints that were provided.
A field’s name is larger than the maximum.
FieldValueTooLarge
Fields
chars: usizeThe number of codepoints that were provided.
A field’s value is larger than the maximum.
FooterTextTooLarge
The footer text is larger than the maximum.
TitleTooLarge
Fields
chars: usizeThe number of codepoints that were provided.
The title is larger than the maximum.
TooManyFields
Fields
amount: usizeThe number of fields that were provided.
There are more than the maximum number of fields in the embed.